@@ -1,3 +1,4 @@
+import os
 import time
 from typing import TYPE_CHECKING
 
@@ -7,6 +8,7 @@ from prometheus_client import (
     Enum,
     Histogram,
     Info,
+    multiprocess,
     start_http_server,
 )
 
@@ -20,6 +22,9 @@ class Monitor(object):
         self.port = port
         self.metrics = {}
 
+        if "PROMETHEUS_MULTIPROC_DIR" in os.environ:
+            multiprocess.MultiProcessCollector(self.registry)
+
     def use_counter(self, name, description, labels):
         if name not in self.metrics:
             self.metrics[name] = Counter(
@@ -59,7 +64,7 @@ class Monitor(object):
         return self.metrics[name]
 
     def state(self, name, labels, state=None):
-        self.metrics[name].state(state)
+        self.metrics[name].labels(**labels).state(state)
 
     def use_histogram(self, name, description):
         if name not in self.metrics:
@@ -93,7 +98,7 @@ class WorkerMonitor(Monitor):
             "worker state, eg: starting, running and stopped",
             labels=["name"],
             states=["starting", "running", "stopped"],
-        )
+        ).labels(name=self.worker.name)
         self.worker_state.state("starting")
         self.worker_operation = self.use_counter(
             "worker_operation",
