@@ -5,13 +5,13 @@ from abc import ABC
 from copy import copy
 from datetime import datetime
 from enum import IntEnum, Enum
-from typing import Optional, List, Dict, Iterator, Type, KeysView, Union, cast
+from typing import Optional, List, Dict, Iterator, Type, KeysView, Union, cast, Any
 from logging import Logger
 
 from pydantic import BaseModel, ByteSize, Field, ValidationError, parse_obj_as
 
 from .exception import PipelineError, PipelineInputError, PipelineOutputError
-from .message import Message, Command, Log, Kind, MessageBase, Definition
+from .message import Message, Command, Log, Kind, MessageBase
 from .monitor import WorkerMonitor as Monitor
 from .tap import DestinationTap, SourceTap
 from .tap import TapKind, SourceSettings, DestinationSettings  # noqa: F401
@@ -27,6 +27,35 @@ class CommandActions(str, Enum):
     Define = "DEFINE"
 
 
+class DefinitionInternal(BaseModel):
+    """ """
+
+    name: str
+    version: str
+    description: str
+    source: SourceSettings
+    destination: DestinationSettings
+    input_schema: Dict[str, Any] = dict()
+    output_schema: Dict[str, Any] = dict()
+
+
+class TapSettings(BaseModel):
+    namespace: Optional[str]
+    topic: str
+
+
+class Definition(BaseModel):
+    """ """
+
+    name: str
+    version: str
+    description: str
+    source: TapSettings
+    destination: TapSettings
+    input_schema: Dict[str, Any] = dict()
+    output_schema: Dict[str, Any] = dict()
+
+
 class WorkerType(IntEnum):
     Normal = 0
     NoInput = 1
@@ -406,6 +435,7 @@ class Processor(Worker):
             self.logger.exception(
                 f"Input validation failed for message {msg}", exc_info=e
             )
+            self.logger.error(msg.json())
             raise PipelineInputError(f"Input validation failed for message {msg}")
 
         try:
@@ -441,12 +471,15 @@ class Processor(Worker):
                 "version": self.version,
                 "description": self.description,
             }
+            dct["source"] = self.source.settings
+            if self.has_output():
+                dct["destination"] = self.destination.settings
             if self.input_class:
                 dct["input_schema"] = self.input_class.schema()
             if self.output_class:
                 dct["output_schema"] = self.output_class.schema()
 
-            definition = Definition(**dct)
+            definition = DefinitionInternal(**dct)
             updated = cmd.update_content(definition)
         else:
             raise PipelineInputError("Unknown command")
